aboutsummaryrefslogtreecommitdiff
path: root/src/patch/patch.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/patch/patch.hh')
-rw-r--r--src/patch/patch.hh6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/patch/patch.hh b/src/patch/patch.hh
index aa64e0d..56300a9 100644
--- a/src/patch/patch.hh
+++ b/src/patch/patch.hh
@@ -162,7 +162,7 @@ public:
// are two patches really the same patch?
// n.b. this does *not* compare any of the gridfn data!
bool operator==(const patch& other_patch) const
- { return patch_number() == other_patch.patch_number(); }
+ { return this == &other_patch; }
bool operator!=(const patch& other_patch) const
{ return ! operator==(other_patch); }
@@ -475,8 +475,8 @@ public:
int irho, int isigma) // specifies point
const;
- // which ghost zone contains a specified point?
- ghost_zone& ghost_zone_containing_point(int irho, int isigma)
+ // which ghost zone contains a specified noncorner point?
+ ghost_zone& ghost_zone_containing_noncorner_point(int irho, int isigma)
const;